FlushbarRemoteEvent class

A notification payload parsed from a FlushKit SSE message.

Constructors

FlushbarRemoteEvent({String? title, required String message, required Color backgroundColor, required Duration duration, required FlushbarPosition position})
const

Properties

backgroundColor Color
The background colour of the Flushbar.
final
duration Duration
How long the Flushbar stays visible.
final
hashCode int
The hash code for this object.
no setterinherited
message String
The main notification message.
final
position FlushbarPosition
Whether the Flushbar appears at the FlushbarPosition.TOP or FlushbarPosition.BOTTOM of the screen.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
The optional title shown in the Flushbar.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited